#
# spec file for package corosync
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

# Conditionals
# Invoke "rpmbuild --without <feature>" or "rpmbuild --with <feature>"
# to disable or enable specific features
%bcond_without testagents
%bcond_with watchdog
%bcond_with monitoring
%bcond_with snmp
%bcond_with rdma
%bcond_with dbus
%bcond_with upstart
%bcond_with xmlconf
%bcond_without runautogen
%bcond_without systemd
%bcond_without qdevices
%bcond_without qnetd

%if 0%{?sles_version} == 12
%ifnarch s390 s390x
%define buildib 1
%endif
%endif
%if 0%{?suse_version}
%define _libexecdir %{_libdir}
%endif

Name:           corosync
Summary:        The Corosync Cluster Engine and Application Programming Interfaces
License:        BSD-3-Clause
Group:          Productivity/Clustering/HA
Version:        2.4.4
Release:        lp151.5.3.1
Url:            http://corosync.github.io/corosync/
Source0:        %{name}-%{version}.tar.gz
Source2:        baselibs.conf
Patch1:         corosync-init-lockfile-path-error.patch
Patch2:         bnc#872651-stop-cluster.patch
Patch3:         bnc#882449-corosync-conf-example.patch
Patch4:         corosync-2.3.4-fix-bashisms.patch
Patch5:         bsc#1001164-corosync.conf-example.patch
Patch6:         corosync-start-stop-level.patch
Patch7:         disable-build-html-docs.patch
Patch8:         0001-coroapi-Use-size_t-for-private_data_size.patch
Patch9:         0002-fix-ifdown-udp.patch
Patch10:        0003-fix-tmpfiles-create.patch
Patch11:        0004-mark-corosync-as-a-static-service.patch
Patch12:        0005-do-not-convert-empty-uid-gid-to-0.patch
Patch13:        0006-Fix-compile-warnings-with-GCC-7.2.1.patch
Patch14:        0007-add-config-for-corosync-qnetd.patch
Patch15:        0008-bsc#1083561-upgrade-from-1-x-y.patch
Patch16:        0009-bsc#1088619-add-version.patch
Patch17:        0010-qdevice-net-instance.c-optarg-should-be-str.patch
Patch18:        0011-NSS_NoDB_Init-the-parameter-is-reserved-must-be-NULL.patch
Patch19:        0012-cpg-Inform-clients-about-left-nodes-during-pause.patch
Patch20:        bug-1163460-totemip-Add-support-for-sin6_scope_id.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# openais is indeed gone and should be uninstalled. Yes, we do not
# provide openais on purpose, the package has been deleted.
Obsoletes:      openais < 1.2
Conflicts:      openais < 1.2

# Runtime bits
Requires:       libcfg6 = %{version}-%{release}
Requires:       libcmap4 = %{version}-%{release}
Requires:       libcorosync_common4 = %{version}-%{release}
Requires:       libcpg4 = %{version}-%{release}
Requires:       libquorum5 = %{version}-%{release}
Requires:       libsam4 = %{version}-%{release}
Requires:       libtotem_pg5 = %{version}-%{release}
Requires:       libvotequorum8 = %{version}-%{release}
Requires(pre): /usr/sbin/useradd
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig
Conflicts:      openais <= 0.89, openais-devel <= 0.89

# Build bits

BuildRequires:  groff
BuildRequires:  libqb-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  zlib-devel
%if %{with runautogen}
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
%endif
%if %{with monitoring}
BuildRequires:  libstatgrab-devel
%endif
%if %{with rdma}
BuildRequires:  libibverbs-devel
BuildRequires:  librdmacm-devel
%endif
%if %{with snmp}
BuildRequires:  net-snmp-devel
%endif
%if %{with dbus}
BuildRequires:  dbus-1-devel
%endif
%if %{with systemd}
BuildRequires:  pkgconfig(systemd)
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%endif
%if %{with xmlconf}
Requires:       libxslt
%endif
%if %{with qdevices} || %{with qnetd}
Requires:       mozilla-nss-tools
%endif
%if %{with qnetd}
BuildRequires:  sed
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%prep
%setup -q -n %{name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1

%build
%if %{with runautogen}
./autogen.sh
%endif

%if %{with rdma}
export ibverbs_CFLAGS=-I/usr/include/infiniband \
export ibverbs_LIBS=-libverbs \
export rdmacm_CFLAGS=-I/usr/include/rdma \
export rdmacm_LIBS=-lrdmacm \
%endif
%{configure} \
%if %{with testagents}
	--enable-testagents \
%endif
%if %{with watchdog}
	--enable-watchdog \
%endif
%if %{with monitoring}
	--enable-monitoring \
%endif
%if %{with snmp}
	--enable-snmp \
%endif
%if %{with dbus}
	--enable-dbus \
%endif
%if %{with rdma}
	--enable-rdma \
%endif
%if %{with systemd}
	--enable-systemd \
%endif
%if %{with upstart}
	--enable-upstart \
%endif
%if %{with xmlconf}
	--enable-xmlconf \
%endif
%if %{with qdevices}
	--enable-qdevices \
%endif
%if %{with qnetd}
	--enable-qnetd \
%endif
	--with-initddir=%{_initrddir} \
	--with-systemddir=%{_unitdir} \
	--with-upstartdir=%{_sysconfdir}/init \
	--with-tmpfilesdir=%{_tmpfilesdir}

make %{_smp_mflags}

%install
%make_install

%if %{with dbus}
mkdir -p -m 0700 %{buildroot}/%{_sysconfdir}/dbus-1/system.d
install -m 644 %{_builddir}/%{name}-%{version}/conf/corosync-signals.conf %{buildroot}/%{_sysconfdir}/dbus-1/system.d/corosync-signals.conf
%endif
%if %{with systemd}
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rccorosync
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rccorosync-qnetd
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rccorosync-qdevice
ln -s /usr/sbin/service %{buildroot}%{_sbindir}/rccorosync-notifyd
%endif

## tree fixup
# drop static libs
rm -f %{buildroot}%{_libdir}/*.a
rm -f %{buildroot}%{_libdir}/*.la
# drop docs and html docs for now
rm -rf %{buildroot}%{_docdir}/*
#remove init scripts for corosync, corosync-qdevice, corosync-qnetd
rm -rf init/corosync init/corosync-qnetd init/corosync-qdevice
mkdir -p  %{buildroot}/usr/lib/tmpfiles.d/
mkdir -p  %{buildroot}/usr/share/doc/packages/corosync/
mkdir -p  %{buildroot}%{_fillupdir}/
mkdir -p  %{buildroot}%{_sysconfdir}/init.d/
install -m 0644 tools/corosync-notifyd.sysconfig.example  %{buildroot}/usr/lib/tmpfiles.d/corosync-notifyd
install -m 0644 conf/corosync.conf.example* %{buildroot}/usr/share/doc/packages/corosync/
mkdir -p %{buildroot}/usr/lib/corosync
install -m 0755 init/upgrade.sh %{buildroot}/usr/lib/corosync
rm -rf %{buildroot}/etc/corosync/corosync.conf.example*
rm -rf %{buildroot}/etc/logrotate.d/
mkdir -p %{buildroot}%{_sysconfdir}/sysconfig
install -m 644 init/corosync.sysconfig.example \
   %{buildroot}%{_fillupdir}/sysconfig.corosync
rm -rf %{buildroot}%{localstatedir}/run/
%if %{with qdevices}
install -m 644 init/corosync-qdevice.sysconfig.example \
   %{buildroot}%{_fillupdir}/sysconfig.corosync-qdevice
install -m 770 -d %{buildroot}/run/corosync-qdevice
%endif

%if %{with qnetd}
install -m 644 init/corosync-qnetd.sysconfig.example \
   %{buildroot}%{_fillupdir}/sysconfig.corosync-qnetd
install -m 770 -d %{buildroot}/run/corosync-qnetd
%if %{with systemd}
sed -i -e 's/^#User=/User=/' \
   %{buildroot}%{_unitdir}/corosync-qnetd.service
%else
sed -i -e 's/^COROSYNC_QNETD_RUNAS=""$/COROSYNC_QNETD_RUNAS="coroqnetd"/' \
   %{buildroot}%{_sysconfdir}/sysconfig/corosync-qnetd
%endif
%endif

%description
This package contains the Corosync Cluster Engine Executive, several default
APIs and libraries, default configuration files, and an init script.

%pre
%service_add_pre corosync.service corosync-notifyd.service

%post
/usr/lib/corosync/upgrade.sh
%tmpfiles_create /usr/lib/tmpfiles.d/corosync-notifyd
%{fillup_and_insserv -n corosync}
%service_add_post corosync.service corosync-notifyd.service

rm -rf  %{_sysconfdir}/corosync/corosync.conf.example %{_sysconfdir}/corosync/corosync.conf.example.unicast
ln -s /usr/share/doc/packages/corosync/corosync.conf.example %{_sysconfdir}/corosync/
ln -s /usr/share/doc/packages/corosync/corosync.conf.example.udpu %{_sysconfdir}/corosync/corosync.conf.example.unicast

%preun
%service_del_preun corosync.service corosync-notifyd.service

%postun
if [ -f /etc/sysconfig/corosync ]; then
    rm /etc/sysconfig/corosync
fi

%files
%defattr(-,root,root,-)
%doc LICENSE SECURITY
%{_sbindir}/corosync
%{_sbindir}/corosync-keygen
%{_sbindir}/corosync-cmapctl
%{_sbindir}/corosync-cfgtool
%{_sbindir}/corosync-cpgtool
%{_sbindir}/corosync-quorumtool
%{_sbindir}/corosync-notifyd
%if %{with systemd}
%{_sbindir}/rccorosync
%{_sbindir}/rccorosync-notifyd
%endif
%{_bindir}/corosync-blackbox
%if %{with xmlconf}
%{_bindir}/corosync-xmlproc
%config(noreplace) %{_sysconfdir}/corosync/corosync.xml.example
%dir %{_datadir}/corosync
%{_datadir}/corosync/xml2conf.xsl
%{_mandir}/man8/corosync-xmlproc.8*
%{_mandir}/man5/corosync.xml.5*
%endif
%dir %{_sysconfdir}/corosync
%dir %{_sysconfdir}/corosync/uidgid.d
%dir %{_datadir}/doc/corosync/
%dir /usr/lib/corosync/
/usr/lib/corosync/upgrade.sh
%config(noreplace) /usr/share/doc/packages/corosync/corosync.conf.example
%config(noreplace) /usr/share/doc/packages/corosync/corosync.conf.example.udpu
%config(noreplace) /usr/lib/tmpfiles.d/corosync-notifyd
%config(noreplace) %{_fillupdir}/sysconfig.corosync

%if %{with dbus}
%{_sysconfdir}/dbus-1/system.d/corosync-signals.conf
%endif
%if %{with snmp}
%{_datadir}/snmp/mibs/COROSYNC-MIB.txt
%endif
%if %{with systemd}
%{_unitdir}/corosync.service
%{_unitdir}/corosync-notifyd.service
%dir %{_datadir}/corosync
%{_datadir}/corosync/corosync
%{_datadir}/corosync/corosync-notifyd
%endif
%if %{with upstart}
%{_sysconfdir}/init/corosync.conf
%{_sysconfdir}/init/corosync-notifyd.conf
%endif
%dir %{_localstatedir}/lib/corosync
%dir %{_localstatedir}/log/cluster
%{_mandir}/man8/corosync_overview.8*
%{_mandir}/man8/corosync.8*
%{_mandir}/man8/corosync-blackbox.8*
%{_mandir}/man8/corosync-cmapctl.8*
%{_mandir}/man8/corosync-keygen.8*
%{_mandir}/man8/corosync-cfgtool.8*
%{_mandir}/man8/corosync-cpgtool.8*
%{_mandir}/man8/corosync-notifyd.8*
%{_mandir}/man8/corosync-quorumtool.8*
%{_mandir}/man5/corosync.conf.5*
%{_mandir}/man5/votequorum.5*
%{_mandir}/man8/cmap_keys.8*
%{_datadir}/doc/corosync/*
# optional testagent rpm
#
%if %{with testagents}

%package -n corosync-testagents
Summary:        The Corosync Cluster Engine Test Agents
Group:          Development/Tools/Other
Requires:       %{name} = %{version}

%description -n corosync-testagents
This package contains corosync test agents.

%files -n corosync-testagents
%defattr(755,root,root,-)
%dir %{_datadir}/corosync/tests

%{_datadir}/corosync/tests/mem_leak_test.sh
%{_datadir}/corosync/tests/net_breaker.sh
%{_datadir}/corosync/tests/cmap-dispatch-deadlock.sh
%{_datadir}/corosync/tests/shm_leak_audit.sh
%{_bindir}/cpg_test_agent
%{_bindir}/sam_test_agent
%{_bindir}/votequorum_test_agent

%endif

%package -n libcfg6
Summary:        Corosync configuration database library
Group:          System/Libraries

%description -n libcfg6
This package contains the Corosync configuration database library.

%package -n libcmap4
Summary:        Corosync configuration map library
Group:          System/Libraries

%description -n libcmap4
The CMAP library is used to interact with the configuration database
used by Corosync. The library provides a mechanism to
create/chage/remove keys, iterate over them and track changes to
keys.

%package -n libcorosync_common4
Summary:        The Corosync Cluster Engine library
# openais is indeed gone and should be uninstalled. Yes, we do not
# provide libopenais on purpose, the package has been deleted.
Group:          System/Libraries
Obsoletes:      libopenais3 < 1.2
Conflicts:      libopenais3 < 1.2
Obsoletes:      libcorosync4 < %{version}-%{release}
Provides:       libcorosync4 = %{version}-%{release}

%description -n libcorosync_common4
This package contains the central Corosync library.

%package -n libcpg4
Summary:        Corosync group message API
Group:          System/Libraries

%description -n libcpg4
A group message API called CPG, part of Corosync. This library is
used to create distributed applications that operate properly during
cluster partitions, merges, and faults.

%package -n libquorum5
Summary:        Corosync quorum library
Group:          System/Libraries

%description -n libquorum5
The quorum library is the external interface to the quorum service.
This service is loaded into all nodes in a Corosync cluster and track
the quorum status of a node.

%package -n libsam4
Summary:        Corosync Simple Availability Manager API
Group:          System/Libraries

%description -n libsam4
The SAM library provide a tool to check the health of an application.
The main purpose of SAM is to restart a local process when it fails
to respond to a healthcheck request in a configured time interval.

%package -n libtotem_pg5
Summary:        Corosync Totem protocol 
Group:          System/Libraries

%description -n libtotem_pg5
An implementation of the Totem Single Ring Ordering and Membership
protocol providing the Extended Virtual Synchrony model for messaging
and membership.

%package -n libvotequorum8
Summary:        Corosync vote quorum library
Group:          System/Libraries

%description -n libvotequorum8
The votequorum library is the external interface to the vote-based
quorum service. This service is optionally loaded into all nodes in a
Corosync cluster to avoid split-brain situations. It does this by
having a number of votes assigned to each system in the cluster and
ensuring that only when a majority of the votes are present, cluster
operations are allowed to proceed.

%files -n libcfg6
%defattr(-,root,root)
%{_libdir}/libcfg.so.*

%files -n libcmap4
%defattr(-,root,root)
%{_libdir}/libcmap.so.*

%files -n libcpg4
%defattr(-,root,root)
%{_libdir}/libcpg.so.*

%files -n libcorosync_common4
%defattr(-,root,root)
%{_libdir}/libcorosync_common.so.*

%files -n libquorum5
%defattr(-,root,root)
%{_libdir}/libquorum.so.*

%files -n libsam4
%defattr(-,root,root)
%{_libdir}/libsam.so.*

%files -n libtotem_pg5
%defattr(-,root,root)
%{_libdir}/libtotem_pg.so.*

%files -n libvotequorum8
%defattr(-,root,root)
%{_libdir}/libvotequorum.so.*

%post   -n libcfg6 -p /sbin/ldconfig
%postun -n libcfg6 -p /sbin/ldconfig
%post   -n libcmap4 -p /sbin/ldconfig
%postun -n libcmap4 -p /sbin/ldconfig
%post   -n libcorosync_common4 -p /sbin/ldconfig
%postun -n libcorosync_common4 -p /sbin/ldconfig
%post   -n libcpg4 -p /sbin/ldconfig
%postun -n libcpg4 -p /sbin/ldconfig
%post   -n libquorum5 -p /sbin/ldconfig
%postun -n libquorum5 -p /sbin/ldconfig
%post   -n libsam4 -p /sbin/ldconfig
%postun -n libsam4 -p /sbin/ldconfig
%post   -n libtotem_pg5 -p /sbin/ldconfig
%postun -n libtotem_pg5 -p /sbin/ldconfig
%post   -n libvotequorum8 -p /sbin/ldconfig
%postun -n libvotequorum8 -p /sbin/ldconfig

%package -n libcorosync-devel
Summary:        The Corosync Cluster Engine Development Kit
Group:          Development/Libraries/C and C++
Requires:       libcfg6 = %{version}-%{release}
Requires:       libcmap4 = %{version}-%{release}
Requires:       libcorosync_common4 = %{version}-%{release}
Requires:       libcpg4 = %{version}-%{release}
Requires:       libqb-devel
Requires:       libquorum5 = %{version}-%{release}
Requires:       libsam4 = %{version}-%{release}
Requires:       libtotem_pg5 = %{version}-%{release}
Requires:       libvotequorum8 = %{version}-%{release}
Requires:       pkgconfig
Provides:       corosync-devel = %{version}
Obsoletes:      corosync-devel < 0.92-7

%description -n libcorosync-devel
This package contains include files and man pages used to develop using
The Corosync Cluster Engine APIs.

%files -n libcorosync-devel
%defattr(-,root,root,-)
%doc LICENSE
%dir %{_includedir}/corosync/
%{_includedir}/corosync/corodefs.h
%{_includedir}/corosync/cfg.h
%{_includedir}/corosync/cmap.h
%{_includedir}/corosync/corotypes.h
%{_includedir}/corosync/cpg.h
%{_includedir}/corosync/hdb.h
%{_includedir}/corosync/sam.h
%{_includedir}/corosync/quorum.h
%{_includedir}/corosync/votequorum.h
%dir %{_includedir}/corosync/totem/
%{_includedir}/corosync/totem/totem.h
%{_includedir}/corosync/totem/totemip.h
%{_includedir}/corosync/totem/totempg.h
%{_libdir}/libcfg.so
%{_libdir}/libcpg.so
%{_libdir}/libcmap.so
%{_libdir}/libtotem_pg.so
%{_libdir}/libquorum.so
%{_libdir}/libvotequorum.so
%{_libdir}/libsam.so
%{_libdir}/libcorosync_common.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/cpg_*3*
%{_mandir}/man3/quorum_*3*
%{_mandir}/man3/votequorum_*3*
%{_mandir}/man3/sam_*3*
%{_mandir}/man8/cpg_overview.8*
%{_mandir}/man8/votequorum_overview.8*
%{_mandir}/man8/sam_overview.8*
%{_mandir}/man3/cmap_*3*
%{_mandir}/man8/cmap_overview.8*
%{_mandir}/man8/quorum_overview.8*
%post -n libcorosync-devel -p /sbin/ldconfig
%postun -n libcorosync-devel -p /sbin/ldconfig

%if %{with qdevices}

%package -n corosync-qdevice
Summary:        The Corosync Cluster Engine Qdevice
Group:          System/Base
Requires:       corosync
Requires:       mozilla-nss-tools

%if %{with systemd}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%endif

%description -n corosync-qdevice
This package contains the Corosync Cluster Engine Qdevice, script for creating
NSS certificates and an init script.

%pre -n corosync-qdevice
%service_add_pre corosync-qdevice.service

%post -n corosync-qdevice
%{fillup_and_insserv -n corosync-qdevice}
%if %{sles_version} > 0
ln -s /run/corosync-qdevice /var/run/
%endif
%service_add_post corosync-qdevice.service

%preun -n corosync-qdevice
%service_del_preun corosync-qdevice.service

%if %{sles_version}
unlink /var/run/corosync-qdevice
%endif

%postun -n corosync-qdevice
if [ -f /etc/sysconfig/corosync-qdevice ]; then
    rm /etc/sysconfig/corosync-qdevice
fi
%service_del_postun corosync-qdevice.service

%files -n corosync-qdevice
%defattr(-,root,root,-)
%dir %{_sysconfdir}/corosync/qdevice
%dir %config(noreplace) %{_sysconfdir}/corosync/qdevice/net
#change corosync-qdevice to /run as /var/run is symlink nowdays
%ghost /run/corosync-qdevice
%{_sbindir}/corosync-qdevice
%{_sbindir}/corosync-qdevice-net-certutil
%{_sbindir}/corosync-qdevice-tool
%config(noreplace) %{_fillupdir}/sysconfig.corosync-qdevice
%if %{with systemd}
%{_unitdir}/corosync-qdevice.service
%{_sbindir}/rccorosync-qdevice
%dir %{_datadir}/corosync
%{_datadir}/corosync/corosync-qdevice
%endif
%{_mandir}/man8/corosync-qdevice-tool.8*
%{_mandir}/man8/corosync-qdevice-net-certutil.8*
%{_mandir}/man8/corosync-qdevice.8*
%endif

%if %{with qnetd}

%package -n corosync-qnetd
Summary:        The Corosync Cluster Engine Qdevice Network Daemon
Group:          System/Base
Requires:       mozilla-nss-tools
Requires(pre): shadow

%if %{with systemd}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%endif

%description -n corosync-qnetd
This package contains the Corosync Cluster Engine Qdevice Network Daemon, script for creating
NSS certificates and an init script.

%pre -n corosync-qnetd
getent group coroqnetd >/dev/null || groupadd -r coroqnetd -g 701
getent passwd coroqnetd >/dev/null || useradd -r -g coroqnetd -u 701 -s /sbin/nologin -c "User for corosync-qnetd" coroqnetd

%service_add_pre corosync-qnetd.service

exit 0

%post -n corosync-qnetd
%if %{sles_version} > 0
ln -s /run/corosync-qnetd /var/run/
%endif
%{fillup_and_insserv -n corosync-qnetd}

%service_add_post corosync-qnetd.service

%preun -n corosync-qnetd
%service_del_preun corosync-qnetd.service

%if %{sles_version} > 0
unlink /var/run/corosync-qnetd
%endif

%postun -n corosync-qnetd
if [ -f /etc/sysconfig/corosync-qnetd ];then
    rm /etc/sysconfig/corosync-qnetd
fi
%service_del_postun corosync-qnetd.service

%files -n corosync-qnetd
%defattr(-,root,root,-)
%dir %config(noreplace) %attr(750, coroqnetd, coroqnetd) %{_sysconfdir}/corosync/qnetd
#change corosync-qnetd to /run as /var/run is just symlink nowadays
%ghost %attr (750, coroqnetd, coroqnetd) /run/corosync-qnetd
%{_bindir}/corosync-qnetd
%{_bindir}/corosync-qnetd-certutil
%{_bindir}/corosync-qnetd-tool
%config(noreplace) %{_fillupdir}/sysconfig.corosync-qnetd
%if %{with systemd}
%{_unitdir}/corosync-qnetd.service
%{_sbindir}/rccorosync-qnetd
%dir %{_datadir}/corosync
%{_datadir}/corosync/corosync-qnetd
%endif
%{_mandir}/man8/corosync-qnetd-tool.8*
%{_mandir}/man8/corosync-qnetd-certutil.8*
%{_mandir}/man8/corosync-qnetd.8*
%endif

%changelog
* Fri Mar 20 2020 XinLiang <XLiang@suse.com>
- Fix bsc#1163460 Corosync does not support link-local IPv6 addresses
  Added: bug-1163460-totemip-Add-support-for-sin6_scope_id.patch
* Wed May  2 2018 bliu@suse.com
- cpg: Inform clients about left nodes during pause(bsc#1091593)
    Added: 0012-cpg-Inform-clients-about-left-nodes-during-pause.patch
* Thu Apr 26 2018 bliu@suse.com
- NSS_NoDB_Init: the parameter is reserved, must be NULL(bsc#1090996)
    Added: 0011-NSS_NoDB_Init-the-parameter-is-reserved-must-be-NULL.patch
* Tue Apr 17 2018 bliu@suse.com
- corosync-2.4.4 is available now(bsc#1089836)
    man:fix in corosync-qdevice.8
    quorumtool: remove duplicated help message
    cfg: nodeid should be unsigned int
    coroparse: Use readdir instead of readdir_r
    wd: fix snprintf warnings
    Fix compile errors in qdevice on FreeBSD
    qdevice: mv free(str) after port validation
    Fix various typos
    Fix typo: recomended -> recommended
    man: support SOURCE_DATE_EPOCH
    configure: add --with-initconfigdir option
    Use static case blocks to determine distro flavor
    Use RuntimeDirectory instead of tmpfiles.d
    coroparse: Do not convert empty uid, gid to 0
    sam: Fix snprintf compiler warnings
    quorumtool: Use full buffer size in snprintf
    man: Add note about qdevice parallel cmds start
    sync: Remove unneeded determine sync code
    sync: Call sync_init of all services at once
    corosync.conf: publicize nodelist.node.name
    totemudp[u]: Drop truncated packets on receive
    logging: Make blackbox configurable
    logging: Close before and open blackbox after fork
    init: Quote subshell result properly
    blackbox: Quote subshell result properly
    qdevice: quote certutils scripts properly
    sam_test_agent: Remove unused assignment
    qdevice: Fix NULL pointer dereference
    quorumtool: Don't set our_flags without v_handle
    qdevice: Nodelist is set into string not array
    qdevice: Check if user_data can be dereferenced
    qdevice: Add safer wrapper of strtoll
    qdevice: Replace strtol by strtonum
    qnetd: Replace strtol by strtonum
    main: Set errno before calling of strtol
    totemcrypto: Implement bad crypto header guess
    cpg: Use list_del instead of qb_list_del
    totemcrypto: Check length of the packet
    totemsrp: Implement sanity checks of received msgs
    totemsrp: Check join and leave msg length
    totemudp: Check lenght of message to sent
    qdevice msgio: Fix reading of msg longer than i32
    logsys: Avoid redundant callsite section checking
    man: corosync-qdevice: fix formatting vs. punctuation
    man: corosync-qdevice: some more stylistics
    man: fix cpg_mcast_joined.3.in
    libcpg: Fix issue with partial big packet assembly
    totempg: Fix fragmentation segfault
    totempg: use iovec[i].iov_len instead of copy_len
    totempg: Fix corrupted messages
    cpg: Handle fragmented message sending interrupt
    corosync.aug: Add missing options
    systemd: Delete unnecessary soft_margin
    Added:
    corosync-2.4.4.tar.gz
    0010-qdevice-net-instance.c-optarg-should-be-str.patch
    Deleted:
    0007-sync-Call-sync_init-of-all-services-at-once.patch
    0008-wd-fix-snprintf-warnings.patch
    0009-add-config-for-corosync-qnetd.patch
    0010-qdevice-mv-free-str-after-port-validation.patch
    0011-libcpg-Fix-issue-with-partial-big-packet-assembly.patch
    0012-totemudp-u-Drop-truncated-packets-on-receive.patch
    0013-logging-Make-blackbox-configurable.patch
    0014-logging-Close-before-and-open-blackbox-after-fork.patch
    0015-coverity-fixes.patch
    0018-bsc#1089346-corosync-Integer-overflow-in-totemcrypto.patch
    corosync-2.4.3.tar.gz
    Renamed:
    0009-add-config-for-corosync-qnetd.patch -> 0007-add-config-for-corosync-qnetd.patch
    0016-bsc#1083561-upgrade-from-1-x-y.patch -> 0008-bsc#1083561-upgrade-from-1-x-y.patch
    0017-bsc#1088619-add-version.patch -> 0009-bsc#1088619-add-version.patch
* Fri Apr 13 2018 bliu@suse.com
-  (CVE-2018-1084) VUL-0: CVE-2018-1084: corosync: Integer overflow in totemcrypto(bsc#1089346)
    Added: 0018-bsc#1089346-corosync-Integer-overflow-in-totemcrypto.patch
* Tue Apr 10 2018 bliu@suse.com
- UNKNOWN version in corosync pkg-config(bsc#1088619)
    Added: 0017-bsc#1088619-add-version.patch
* Thu Mar  8 2018 bliu@suse.com
- [Build 489.1] Corosync is not working after upgrade from sle11sp4-ha to sle15-ha(bsc#1083561)
    Added: 0016-bsc#1083561-upgrade-from-1-x-y.patch
* Mon Mar  5 2018 bliu@suse.com
- some coverity fixes for corosync on upstream(bsc#1083895)
    Added: 0015-coverity-fixes.patch
* Wed Jan 31 2018 bliu@suse.com
- corosync exposes itself for a self-crash under rare circumstance(bsc#1078412)
    Added: 0013-logging-Make-blackbox-configurable.patch
    0014-logging-Close-before-and-open-blackbox-after-fork.patch
    Modified: remove unncessary git commit messages
    0001-coroapi-Use-size_t-for-private_data_size.patch
    0002-fix-ifdown-udp.patch
    0005-do-not-convert-empty-uid-gid-to-0.patch
    0008-wd-fix-snprintf-warnings.patch
    0010-qdevice-mv-free-str-after-port-validation.patch
    0011-libcpg-Fix-issue-with-partial-big-packet-assembly.patch
    0012-totemudp-u-Drop-truncated-packets-on-receive.patch
* Wed Jan 10 2018 bliu@suse.com
- totemudp[u]: Drop truncated packets on receive(bsc#1075300)
    Added: 0012-totemudp-u-Drop-truncated-packets-on-receive.patch
* Thu Jan  4 2018 bliu@suse.com
- issue with partial packets assembly when multiple nodes are sending big packets(bsc#1074929)
    Added: 0011-libcpg-Fix-issue-with-partial-big-packet-assembly.patch
* Tue Jan  2 2018 bliu@suse.com
- qdevice failed to run(bsc#1074276)
    Added: 0010-qdevice-mv-free-str-after-port-validation.patch
* Wed Dec 27 2017 bliu@suse.com
- add support for corosync-qdevice in yast2-cluster and bootstrap(bsc#1070961)
    Added: 0009-add-config-for-corosync-qnetd.patch
* Tue Dec  5 2017 bliu@suse.com
- wd: gcc shows snprintf warnings(bsc#1071187)
    Added: 0008-wd-fix-snprintf-warnings.patch
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Nov 17 2017 bliu@suse.com
- corosync race condition when node leaves immediately after joining(bsc#1067958)
    Added: 0007-sync-Call-sync_init-of-all-services-at-once.patch
* Thu Nov  9 2017 bliu@suse.com
- gcc: snprintf gives warning: ‘%%s’ directive output may be truncated writing
    8 bytes into a region of size between 1 and 255(bsc#1066090)
    Added: 0006-Fix-compile-warnings-with-GCC-7.2.1.patch
* Mon Nov  6 2017 bliu@suse.com
- coroparse: uidgid with empty uid or gid results into add uid 0(bsc#1066585)
    Added: 0005-do-not-convert-empty-uid-gid-to-0.patch
    Modified: 0005-do-not-convert-empty-uid-gid-to-0.patch,
    check whether the uid, gid is empty before calling strtol
* Mon Oct 23 2017 bliu@suse.com
- Upgrade corosync-2.4.2 to corosync-2.4.3(fate#321385)
    doc: document watchdog_device parameter
    Main: Call mlockall after fork
    Totempg: remove duplicate memcpy in mcast_msg func
    Qdevice: fix spell errors in qdevice
    logconfig: Do not overwrite logger_subsys priority
    totemconfig: Prefer nodelist over bindnetaddr
    cpghum: Fix printf of size_t variable
    Qnetd lms: Use UTILS_PRI_RING_ID printf format str
    wd: Report error when close of wd fails
    votequorum: Don't update expected_votes display if value is too high
    votequorum: simplify reconfigure message handling
    quorumtool: Add option to show all node addresses
    main: Don't ask libqb to handle segv, it doesn't work
    man: Document -a option to corosync-quorumtool
    main: use syslog & printf directly for early log messages
    votequorum: make atb consistent on nodelist reload
    Fix typo: Destorying -> Destroying
    init: Add doc URIs to the systemd service files
    wd: fix typo
    corosync.conf.5: Fix watchdog documentation
    corosync.conf.5: add warning about slow watchdogs
    wd: remove extra capitalization typo
    corosync.conf.5: watchdog support is conditional
    notifyd: Add the community name to an SNMP trap
    Logsys: Change logsys syslog_priority priority
    totemrrp: Fix situation when all rings are faulty
    main: Display reason why cluster cannot be formed
    totem: Propagate totem initialization failure
    totemcrypto: Refactor symmetric key importing
    totemcrypto: Use different method to import key
    main: Add option to set priority
    main: Add support for libcgroup
    totemcrypto: Fix compiler warning
    cmap: Remove noop highest config version check
    qdevice: Add support for heuristics
    Spec: drop unneeded dependency
    Spec: make internal dependencies arch-qualified
    cmap: don't shutdown highest config_version node
    totemudp: Remove memb_join discarding
    Spec: fix arch-qualified dependencies
    Include fcntl.h for F_* and O_* defines
    totemudp: Retry if bind fails
    Remove deprecated doxygen flags
    man: Fix typos in man page
    man: Modify man-page according to command usage
    Remove redundant header file inclusion
    upstart: Add softdog module loading example
    Added:
    corosync-2.4.3.tar.gz
    Removed:
    corosync-2.4.2.tar.gz
    bsc#1047860-add-version.patch
    0001-Logsys-Change-logsys-syslog_priority-priority.patch
    0001-logconfig.c-make-logging.syslog_priority-and-logging.patch
    0001-totemconfig.c-Fixed-Evicted-from-CPG-membership.patch
    0002-Main-call-mlock-after-fork.patch
    0003-totemrrp-Fix-situation-when-all-rings-are-faulty.patch
    0004-main-Display-reason-why-cluster-cannot-be-formed.patch
    0005-votequorum-Report-errors-from-votequorum_exec_send_r.patch
    0007-Make-corosync-work-when-FIPS-mode-is-enabled.patch
    0008-main.c-add-option-to-set-priority.patch
    0009-totem-Propagate-totem-initialization-failure.patch
    Modified:
    bsc#1047860-add-version.patch: change version to 2.4.3
    corosync.changes: add changelogs
    corosync.spec: remove unnecessary patches
    Renamed:
    0006-coroapi-Use-size_t-for-private_data_size.patch -> 0001-coroapi-Use-size_t-for-private_data_size.patch
    0010-fix-ifdown-udp.patch -> 0002-fix-ifdown-udp.patch
    0011-fix-tmpfiles-create.patch -> 0003-fix-tmpfiles-create.patch
    0012-mark-corosync-as-a-static-service.patch -> 0004-mark-corosync-as-a-static-service.patch
* Thu Sep 28 2017 bliu@suse.com
- wrong "service_del_postun corosync.service"(bsc#1060767)
    Modified: corosync.spec, remove service_del_postun in postun of corosync
* Tue Sep 12 2017 jengelh@inai.de
- Restore conformance to shared library packaging guideline.
- Remove redundant cleaning in %%install and %%clean.
* Tue Aug 29 2017 bliu@suse.com
- corosync.service should be marked as a static service(bsc#1055585)
    Added: 0012-mark-corosync-as-a-static-service.patch
* Tue Aug  8 2017 jengelh@inai.de
- Fix RPM groups.
* Thu Aug  3 2017 bliu@suse.com
- L3: corosync: assert(sender_node != NULL) fails after tearing down a network interface(bsc#1032634)
    Added: 0010-fix-ifdown-udp.patch
- Fix rpmlint warnings
    Added: 0011-fix-tmpfiles-create.patch
* Thu Aug  3 2017 bliu@suse.com
- some errors in spec file(bsc#1047862)
  Modified:corosync.spec
  1) as in openSUSE:factory, there are %%define, but bcond_with coudld be toggled by osc command , change %%define to %%bcond_with and %%bcond_without
  2) change service_del_postun to service_del_preun, since service_del_postun is not a right macro
  3) remove macro tpmfiles_create define from corosync.spec.
* Mon Jul 31 2017 bliu@suse.com
- make corosync.spec uniform (bsc#1051385)
  Modified: corosync.spec
    1. there are some lines are commented in corosync.spec, will define new macro to make these lines uncommented
    2. in former, xmlconf, rdma and snmp were disabled, these features are wrongly enabled, will disable them
* Wed Jul 12 2017 bliu@suse.com
-  some upstream fixes for corosync(bsc#1048259)
  Added:
    bsc#1047860-add-version.patch
    0007-Make-corosync-work-when-FIPS-mode-is-enabled.patch
    0008-main.c-add-option-to-set-priority.patch
    0009-totem-Propagate-totem-initialization-failure.patch
  Removed:
    bnc#867767-add-version.patch
    0007-improve-corosync-keygen.patch(since this patch is not for corosync v2.x)
  Modified:
    corosync.spec, add judgement whether /etc/sysconfig/corosycn* exist before remove these files
* Mon Jul 10 2017 bliu@suse.com
- some errors in spec file(bsc#1047862)
  Modified:
    corosync.spec
- improvement for corosync-keygen(bsc#1047861)
  Added:
    0007-improve-corosync-keygen.patch
- 1047860corosync report wrong version number(bsc#1047860)
  Modified:
    bnc#867767-add-version.patch
* Wed Jun  7 2017 bliu@suse.com
-  some Fixes from upstream(bsc#1043045)
  Added:
    0004-main-Display-reason-why-cluster-cannot-be-formed.patch
    0005-votequorum-Report-errors-from-votequorum_exec_send_r.patch
    0006-coroapi-Use-size_t-for-private_data_size.patch
* Tue Jun  6 2017 bliu@suse.com
  [patch-lost-in-sle] Missing issues in openSUSE:Factory/corosync(bsc#1041587)
  add change log for upgrading corosync to v2.3.6 and make this change log contain all records in SLE12 SP3
  make the format consistent
* Tue May 16 2017 bliu@suse.com
- totemrrp: Fix situation when all rings are faulty(bsc#1039215)
  Added:
    0003-totemrrp-Fix-situation-when-all-rings-are-faulty.patch
* Tue May  9 2017 bliu@suse.com
- calling mlockall before corosync_tty_detach is noop when corosync is executed as a daemon(bsc#1038147)
  Added:
    0002-Main-call-mlock-after-fork.patch
* Mon Apr 10 2017 bliu@suse.com
- [upgrade] Changing the pre-upgrade role for node failed(bsc#1030437)
  Added:
    0001-totemconfig.c-Fixed-Evicted-from-CPG-membership.patch
  Removed:
    0001-totemip.c-Fixed-Evicted-from-CPG-membership.patch
* Tue Mar 14 2017 bliu@suse.com
- L3-Question: corosync logging priority takes no effect(bsc#1023959)
  Added:
    0001-Logsys-Change-logsys-syslog_priority-priority.patch
    0001-logconfig.c-make-logging.syslog_priority-and-logging.patch
* Tue Dec  6 2016 bliu@suse.com
-  Corosync 2.4.1 still produces libvotequorum.so.7.0.0, just like Corosync 2.3.6.(bsc#1013842)
  Added:
  disable-build-html-docs.patch
  upgrade to corosync-2.4.2:
    Man: Fix corosync-qdevice-net-certutil link
    man: mention qdevice incompatibilites in votequorum.5
    Qnetd LMS: Fix two partition use case
    cfg: Prevents use of uninitialized buffer
* Mon Oct 17 2016 bliu@suse.com
- upgrade to corosync-2.4.1(bsc#1004967)
  Added:
    corosync-start-stop-level.patch
  Deleted:
    Config-Flag-config-uidgid-entries.patch
    cfg-Prevents-use-of-uninitialized-buffer.patch
    cts-Make-it-run-with-pacemaker-1.13.patch
    get_cluster_mcast_addr-error-is-not-fatal.patch
    totemsrp-Addition-of-the-log.patch
  modified: bnc#867767-add-version.patch, change version to 2.4.1
  corosync-2.4.1:
    Low: totemsrp: Addition of the log.
    cts: Make it run with pacemaker-1.13+
    Config: Flag config uidgid entries
    Spec: Qdevice require same version of corosync
  corosync-2.4.0:
    qdevice and qnet
    config: get_cluster_mcast_addr error is not fatal
    some typo fixes
* Sat Oct 15 2016 bliu@suse.com
  upgrade corosync-v2.3.5 to corosync-v2.3.6, and backport patches from v2.4.2(FATE#322113, bsc#1020550)
  Added:
    Config-Flag-config-uidgid-entries.patch
    cfg-Prevents-use-of-uninitialized-buffer.patch
    cts-Make-it-run-with-pacemaker-1.13.patch
    get_cluster_mcast_addr-error-is-not-fatal.patch
    totemsrp-Addition-of-the-log.patch
  Removed:
    corosync-cts-api-error.patch
  v2.3.6
- logconfig: Fix logging reload disabling logfiles
- wd: Warn if values are out of range
- parser: WD Read type correctly from corosync.conf
- Add some more RO keys
- Reapply config defaults corosync.conf reload
- schedwrk: Cleanup and make it work on PPC BE
- cmapctl: Handle corosync errors in print_key func
- Adds doxygen stubs to include directory
- Add clang-format configuration file
- wd: make watchdog device configurable
- logging: Use our own version of basename
- logsys: fix TOTEM logging when corosync built out of tree
- parser: Make config file parser more hierarchy
- totemconfig: Explicitly pass IP version
- cpg: Handle ipc error in cpg_zcb_alloc/free
- cpg: Memory not unmapped in cpg_zcb_free
- totempg: Fix memory leak
- Fix spelling errors
- Add section in manual title for cpg_zcb_free 3
- Add section in manual title for cpg_zcb_alloc 3
- Update corosync.spec source link
- Update gitignore files
- Remove all links to old ML
- totemsrp: Fix clang warning (tautological compare)
- configure.ac: Make location of .pc overrideable
- Remove a few unused variables and functions
- configure.ac: We don't need no C++ compiler
- configure.ac: Remove deprecated AC_PROG_LIBTOOL
- configure.ac: make foreign apply to all Makefiles
- Remove unused, obsolete check
- Fix detection of qb_log_thread_priority_set
- cpghum: Fix type of recv_crc
- Check for fdatasync
- Fix detection of warning flags for clang
- quorum: Display node id as unsigned int.
- cts: InitClusterManager is now BootCluster
- totemudp: Move udp bind() so that multicast works with IPv6
- cfgtool: Display nodeid as unsigned int
- votequorum: Don't send multiple callbacks when nodes join
- man: Add synopsis for cpg_zcb_alloc and free
- man html index: Update index
- votequorum: Make sure cs_error_t is defined
- Doxygen fix for cmap_iter_next()
- configure: Correct help entry for logdir
- totmesrp: Fix typo in log message
- configure: typo in include
- man page: Correct option letter for DBus
- wd: fix setting of watchdog timeouts
- CFG: Prevent CFG orignating messages during SYNC
* Tue Sep 27 2016 bliu@suse.com
- Default token timeout was 5000 ms in SLE 11 SP4, but is 1000 ms in SLE 12(bsc#1001164)
  Added: bsc#1001164-corosync.conf-example.patch
* Wed Sep  7 2016 bliu@suse.com
- Fix: [s390]Upgrade from SP1-GM + HA to SP2-RC2 +: Failed to start Corosync Cluster engine(bsc#996230)
- modify corosync.spec to remove "chkconfig --add"
- remove corosync-devel and require lines from baselibs.conf
* Thu Jul 14 2016 bliu@suse.com
-  corosync process still exists when stop pacemaker service(bnc#988683)
* Mon Aug 17 2015 bliu@suse.com
- remove git files from tarball(bnc#941910)
- modify corosync.spec to delete logrotate.d
* Tue Jul 21 2015 bliu@suse.com
  update from v2.3.3 to v2.3.5 (bnc#939328)
  v2.3.5
- Log: Add logrotate configuration file
- totemsrp: Improve logging of left/down nodes
- totemconfig: Check for duplicate nodeids
- Really add cpghum
- cpg: Add support for messages larger than 1Mb
- Handle adding and removing UDPU members atomically
- add patches:
  * corosync-cts-api-error.patch
  * bnc#867767-add-version.patch
* Wed Jul  1 2015 bliu@suse.com
- mv the place of corosync.conf.example*(fate#318190)
* Wed Nov 19 2014 dimstar@opensuse.org
- Replace systemd BuildRequires with pkgconfig(systemd): we do not
  require the full installation / dep chain of systemd.
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashisms in mem_leak_test.sh script
- add patches:
  * corosync-2.3.4-fix-bashisms.patch
* Mon Nov 17 2014 Led <ledest@gmail.com>
- fix bashism in preun script
* Mon Sep  1 2014 xli@suse.com
- Update to corosync 2.3.4
- Drop the obsoleted patches
  - corosync-cts-api-error.patch
  - bnc#867767-add-version.patch
  - bnc#881142-fix-shm-leak.patch
- quorumtool: Sort output by nodeid
- YKD: Fix loading of YKD quorum module
- corosync-quorumtool: add sort options
- cleanup after test-driver
- be consistent in using CPPFLAGS vs CFLAGS
- totemsrp: Fix typo with cont gather
- cpg: Refactor mh_req_exec_cpg_procleave
- cpg: Make sure nodid is always logged as hex num
- cpg: Make sure left nodes are really removed
- mon: Make mon compilable with libstatgrab ver 0.9
- mon: Fix comparsion typo
- mon: Pass correct pointer to inst
- mon: Make monitoring work
- config: Handle totem_set_volatile_defaults errors
- config: Allow dynamic change of token_coefficient
- Log: Make reload of logging work
- Really clear totemconfig nodes on reload
- Add token_coefficient option
- init: Make init script configurable
- totemiba: Fix incorrect failed log message
- logsys: Log error if blackbox cannot be created
- logsys: Log warning if flightrecorder init fails
- Introduce get_run_dir function
- Move ringid store and load from totem library
- coroparse: More strict numbers parsing
- Doc: Enhance INSTALL file a bit
- Make config.reload_in_progress key read only
- Fix compiler warning introduced by previous patch
- totemconfig: Free ifaddrs list
- totemconfig: Make sure join timeout is less than consensus
- totemconfig: Key change process dependencies
- totemconfig: Log errors on key change and reload
- totemconfig: totem_config_get_ip_version
- totemconfig: refactor nodelist_to_interface func
- corosync-keygen: Replace printf/exit call with err
- votequorum: Add cmap key to reset wait_for_all
- votequorum: Return current ring id in callback
- votequorum: Add ring id to poll call
- votequorum: Do not process events during reload
- votequorum: Block sync until qdevice poll
- votequorum: Make qdev timeout in sync configurable
- votequorum: Properly initialize atb and atb_string
- ipc: Process votequorum messages during sync
- testvotequorum2: Opt for polling with old ringid
- TODO: Remove TODO file
- Makefile: Do not install TODO file
- totem: Inform RRP about membership changes
- totemnet: Add totemnet_member_set_active
- totemrrp: Implement *_membership_changed
- totemudpu: Implement member_set_active
- totemudpu: Send msgs to all members occasionally
- Cancel token holding while in retransmition
- upstart: Make job conf file configurable
- systemd: Config example for corosync wd service
- Install doc: Correct a typo
- init: change return value when starting corosync
- Free object allocated at quorum_register_callback
- corosync-cmapctl: Allow -p option to delete keys
- Implement config file testing mode
- Slightly rework corosync-keygen.
- totemiba: Add multicast recovery
- Indent: Remove space in negation of expression
- Indent: Remove newline before else branch start
- fix memory leak produced by 'corosync -v'
- Handle SIGSEGV and SIGABRT signals
* Thu Jul  3 2014 lzhong@suse.com
- comment out line: to_logfile:no (bnc#882449)
  work on patch bnc#882449-corosync-conf-example.patch
* Wed Jul  2 2014 yzou@suse.com
- Fixed shared memory leak.
  + bnc#881142-fix-shm-leak.patch
* Fri Jun 13 2014 lzhong@suse.com
- Update corosync.conf.example and corosync.conf.example.udpu(bnc#882449)
  - remove corosync-conf-example.patch
  + add bnc#882449-corosync-conf-example.patch
* Fri Apr 11 2014 lzhong@suse.com
- Fix `systemctl stop pacemaker` leaves corosync running
  + bnc#872651-stop-cluster.patch
- Ensure that libopenais3 is removed on update of corosync(bnc#872122)
* Wed Mar 12 2014 lzhong@suse.com
- Modify spec file:add symlink rccorosync to /usr/sbin/service (bnc#866057)
- Fix corosync -v show UNKNOW (bnc#867767)
  + bnc#867767-add-version.patch
* Tue Jan 21 2014 xli@suse.com
- Update to corosync 2.3.3
- Properly check result of symlink
- Fix cppchecks warning
- Close devnull file handler
- votequorum: Add missing man pages
- totem: Drop invalid join msg in operational state
- systemd unit: Make sure network is really up
- votequorum: Improve/add documentation for quorum device API
- votequorum: Add persistent expected_votes tracking.
- Upstream version cs: 45dd9861ff78362068d214cf520006a1b26376cd
* Thu Jan  9 2014 xli@suse.com
- Add patch to fix cts api wrong issue
  + corosync-cts-api-error.patch
- Add patch to change default settings of conf.example
  + corosync-conf-example.patch
* Thu Dec 12 2013 xli@suse.com
- Update to corosync 2.3.2
- cfgtool: return error on reload failure
- man pages: Note that votequorum's allow_downscale is unsupported
- logsys: Make logging of totem work again
- totemsrp: Show English message when memb_state_gather_enter is called
- totemiba: Check if configured MTU is allowed by HW
- totemiba: Fix parameters position for poll_add
- totemiba: Del channel fd from poll before destroy
- totemiba: Properly allocate RDMA buffers
- Upstream version cs: 7014f10123a634cf026491edc9a09d6044106116
* Fri Nov 29 2013 lmb@suse.com
- Obsolete openais so that updates work automatically and uninstall the
  openais package.
* Fri Sep 13 2013 xli@suse.com
- Upstream version cs: c6688c6e11a35d13293f9b610faca5c7beb7e5cb
- Reload: document config.reload_in_progress in man page
- Reload: Add atomic reload to log config
- Reload: Add atomic reload to totemconfig
- Reload: Add reload code to cfg
- Reload: Make coroparse use a designated icmap hash table
- icmap: Add func to test equality of two key values
- [PATCH] Replace freopen with open/dup2 when daemonizing
- Add log message to exit signal handler
- icmap: Add map copy function
- icmap: Add function to return item data pointer
- icmap: Fix value len checking for strings
- icmap: Add function to return global icmap
- icmap: Allow multiple icmap instances
- Fix scheduler pause-detection timeout
* Fri Sep  6 2013 xli@suse.com
- Update corosync-2.3.1.tar.gz for cts file missing
* Thu Jul 25 2013 xli@suse.com
- Fix corosync start failed issue
  + corosync-init-lockfile-path-error.patch
* Tue Jul 23 2013 xli@suse.com
- Update to corosync 2.3.1 stable release
- Remove patches for all merged in the upstream or obsoleted
  - corosync-confexample-timestamp.patch
  - corosync-cpg-procdown.patch
  - corosync-revert-cs2429.patch
  - corosync.conf.example.patch
  - corosync_reduce_RR_priority.patch
  - fix-nodeid-conflicting.patch
* Fri May 10 2013 tserong@suse.com
- Update to corosync 1.4.5 stable release (bnc#799031)
- coroipc: Handle pfd.revents as bit-field
- Check socket_recv error code in ipc_dispatch_get
- On places with POLLERR check also POLLNVAL
- coroipc: Don't spin when waiting on semaphore
- log: Handle race in printf_to_logs and format_set
- objdb: Don't read uninitialized memory in inc/dec
- Add waiting_trans_ack also to fragmentation layer
- Handle segfault in backlog_get
- Fix problem with sync operations under very rare circumstances
- manpages: Add confdb_key_get man page
- manpages: Add links for referenced confdb calls
- manpages: Fix typo in evs* manpages
- If failed_to_recv is set, consensus can be empty
- Ignore sync barrier msgs if sync doesn't started
- Make service_build contain correct number of msgs
- Handle sync and service unload correctly
- Don't call sync_* funcs for unloaded services
- Return back "Totem is unable to form..." message
- Move "Totem is unable to form..." message to main
- Use unix socket for local multicast loop
- cpg: Enhance downlist selection algorithm
- cpg: Process join list after downlists
- cpg: Never choose downlist with localnode
- Fix cpg_membership_get()
- Don't access invalid mem in totemconfig
- Move some totem and cpg messages to trace level
- flatiron: Free outq items list on conn exit
- Fix nodeid conflicting issue (bnc#806634)
  + Added fix-nodeid-conflicting.patch
- change the default priority to RR(1) same as pacemaker(bnc#804707)
  + Added corosync_reduce_RR_priority.patch
* Thu Mar 21 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Jun  8 2012 tserong@suse.com
- Update to corosync 1.4.3 stable release.
- Add calls to missing object_find_destroy() to fix mem leaks
- Free mem allocated by getaddrinfo
- corosync.conf.example: change bindnetaddr, mcastaddr, add comments
- Store error str if can't open logfile
- Wait for corosync-notifyd exit in init script
- iba: Use configured node id
- Unlink shm buffers if init fails
- Fix memory leaks when nss fails
- Madvise NOSYNC flag only if available
- Include net/if_var.h header only when needed
- Include stdint.h because funcs uses int16_t
- Use install instead of cp
- Don't unlock mutex in different threads
- Revert "Use install instead of cp"
- Add support for per OS CP flags
- Remove cloned lines in main of main.c
- Fixed bug when corosync receive JoinMSG in OPERATIONAL state
- Correct nodeid of token when we retransmit it
- Correct nodeid in memb_state_commit_token_send function
* Sun Feb  5 2012 jjzhang@suse.com
- Send CPG_REASON_PROCDOWN when really needed (bnc#740343)
* Tue Sep 20 2011 tserong@suse.com
- Changes since corosync 1.4.1 stable release:
  * Resolve a deadlock between the timer and serialize locks.
  * totemconfig: change minimum RRP threshold
  * Ignore memb_join messages during flush operations
  * rrp: Higher threshold in passive mode for mcast (bnc#712037)
  * rrp: Handle endless loop if all ifaces are faulty (bnc#712037)
  * A CPG client can sometimes lockup if the local node is in the downlist
  * Handle errors from totem_mcast
  * coroipcc: use malloc for path in service_connect
  * Version cs: 23112099e1c2b620e6976ca099d2b9afc80721aa
- corosync 1.4.1 stable release:
  * main: let poll really stop before totempg_finalize
  * totemsrp: fix buffer overflows for large clusters (> 100 nodes)
  * rrp: Handle rollower in passive rrp properly
  * rrp: handle rollover in active rrp properly
  * totemconfig: Change default FAIL_TO_RECV_CONST
  * Fix problem where corosync will segfault if there are gaps in recovery
  queue
  * cpgtool/cfgtool: print list of IP with space between items
  * RRP: redundant ring automatic recovery (fate#310284)
  * fix typos in cpg_mcast_joined.3 and cpg_zcb_mcast_joined.3
  * Remove spinlocks
  * confdb: Resolve dispatch deadlock
  * RRP: Fix ring initialization issue for UDPU mode
  * crypto: rng_make_prng prevent buf overflow
  * cpg: do_proc_join change list_slice to list_add
  * totemudp: memset of proper size
  * coroipcs: init buf in coroipcs_handler_dispatch
  * iazc: Reduce number of mem alloc and memcpy
  * coroipcc: Fix unhandled BSD EOF in coroipcc_dispatch_get()
  * cpg: fix sync master selection when one node paused
  * totemsrp: Enhance mcast failure detection
  * coroipcs: Deny connect to service without initfn
  * Add ipc_refcnt to message_handler_req_{exec, lib}_cfg_ringreenable()
- corosync 1.3.1 release:
  * corosync crashing when a network becomes disrupted and then restored
  (bnc#685241)
  * Align IPC on 8 byte boundaries for performance and avoid bus errors.
  * Provide better checking of the message type.
  * totemsrp: free messages originated in recovery rather then rely on
  messages_free
  * Resolve abort during simulatenous stopping of at least 4 nodes.
  * Don't assert when ring id file is less then 8 bytes (possibly after
  local fs problems).
  * Handle delayed multicast packets that occur with switches.
  * CPG: make sure coroipcc_service_disconnect() is always called.
  * Fix abort when token is lost in RECOVERY state (bnc#677779)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Add baselibs configuration
* Tue Feb  8 2011 tserong@novell.com
- Update to corosync 1.3.0
- Set the max buffer size for sockets to reduce message dropping
- diags: add a mechanism to trigger the writing the flight data
- Add the UDPU transport (UDP transport for corosync)
- Remove delay in library on corosync shutdown
- Check for a properly configured multicast address.
- cpg: fix sync'ing the downlist.
- POLL: gracefully handle running out of file descriptors.
- Return CS_ERR_NO_RESOURCES when the server is low on available file
  descriptors.
- Remove checking of subparameters in service.d files.
- Only allow corosync to run one copy via a lock file.
- When used with the openais ckpt service, don't disconnect an ipc
  connection during configuration change that takes longer then 2
  seconds.
- Remove the token cancel retransmit timeout on receipt of a multicast
  message.
* Thu Aug  5 2010 tserong@novell.com
- Update to corosync 1.2.7
  - Remove consensus check for two node cluster cases which can have smaller
    consensus values.  Document in man page the behavior of consensus.
* Tue Jul 27 2010 tserong@novell.com
- Fix problem where flow control could lock up ipc under very heavy load in
  very rare circumstances (upstream cs 3003)
- SYNC: always call sync_aborted() in sync_confchg_fn() (upstream cs 3000)
- SYNCV2: reset the my_memb_determine_ring_id in sync_v2_memb_list_abort()
  (upstream cs 2999)
- Fix logging_daemon config parser code (rhbz#615203) (upstream cs 2998)
- Remove reset of token timeout on retransmitted token reception.  Fixes
  membership problems with certain timing parametrs (upstream cs 2989)
- Speed up IPC connection process (upstream cs 2987)
- Fix fail list fault that occurs in very rare circumstances (upstream cs 2985)
* Thu Jul 22 2010 tserong@novell.com
- Update to corosync 1.2.6
  - 80%% packet loss networks were resulting in problems with totem.
  - Fixed ~40 scanning errors found with coverity.
  - cpg_membership_get now functional.
  - errors logged prior to the start of the daemon were not flushed.
  - Fixes defects in logsys which are crashing pacemaker installations.
  - Adds man pages for all binaries
  - Fixes several defects found in high packet loss field environments.
  - Send proper notification code of CPG_REASON_LEAVE in cpg service.
  - Fix segfault when pacemaker forks new processes
  - Unlock global serializer lock during shutdown to prevent spinning on
    single cpu systems or high cpu use on mulitple cpu systems
  - Stop totem statistics updater timer during shutdown to prevent a
    segfault during shutdown.
  - Fix problem where glibc's fork() implementation may cause segfaults in
    Pacemaker's use of the fork() system call.
  - Fix problem where a full /dev/shm would result in client segfault -
    instead an error is returned in this situation.
  - Fix problem where flight recorder leaks files in shared memory
    filesystem.  Also clean up the error handling of the shared memory
    allocation code of the flight recorder.
  - Fix problem where a failure in glibc's pathconf API would result in
    segfault.
  - Add corosync and corosync-blackbox man pages.
* Fri Jul  9 2010 dmuhamedagic@novell.com
- prevent corosync-cfgtool from hanging (bnc#616183)
* Wed Jun  2 2010 tserong@novell.com
- Set sensible defaults for Pacemaker in corosync.conf.example (bnc#610663)
- Clarify bindnetaddr option in corosync.conf.5 manpage (upstream cs 2856)
* Mon May 10 2010 dmuhamedagic@novell.com
- Handle POLLNVAL in coroipcc
- Save the ring id and restore it properly when the recovery operation fails
- increase maximum entries in the retransmit queue when recovery takes place.
- fix one-off error in memove
- discard and report unknown messages
* Mon Apr 26 2010 dmuhamedagic@novell.com
- fix valgrind reported problems (upstream cs 2787)
  - Memset for res_setup variable in coroipcs:req_setup_send
  - Two memset in logsys for buffers
  - Problem in corosync_totem_stats_updater where
  avg_token_holdtime has size of avg_backlog_calc
  - corosync_totem_stats_init where avg_backlog_calc is 32 bits (not 64)
  - objdb problem if new_valie_len != object->value_len. In
  such case newly allocated memory is not initialized and in some
  situations, value_len is not updated.
- select a new sync member if the node with the lowest nodeid has
  left (upstream cs 2785)
- fix a crash in YKD
* Fri Apr  9 2010 dmuhamedagic@novell.com
- clear the ring id on sync abort (bnc#590666)
- fix unloading of evs
- change sign of all exit codes (normal error exit is now 1)
- objdb: fix key change notifications (don't notify if the key
  wasn't changed; notify on key inc/dec)
- fix possible lockup when a dispatch handler function is NULL
- upstream version cs 2756
* Mon Mar 29 2010 dmuhamedagic@novell.com
- fix lockup that occurs sometimes before exiting
- fix problem where retransmissions don't occur resulting in failure
  to receive condition
- add a reload callback to libconfdb
- support for lib_cpg_finalize
- cpg join with undelivered leave message (fixes problems with nodes
  joining cpg twice in quick succession)
- fix error handling to avoid segfaults/leaks on error
  in coroipcc_service_connect
- upstream release 1.2.1
* Thu Mar  4 2010 dmuhamedagic@novell.com
- retain nodeid compatibility with openais (revert patch from cs 2429)
* Wed Mar  3 2010 jjzhang@novell.com
- minor enhancement to corosync.conf man page (bnc#580180)
* Tue Mar  2 2010 dmuhamedagic@novell.com
- upstream version cs 2667
- allow empty (default) consensus timeout
- fix freeze of IPC library connection on sem_wait
- fix malloc deadlock in signal handler (rhbz#547511)
- fix coroipcs message corruption that occurs when a message fills the
  remainder of the dispatch buffer with a full message
- totemsrp: fix transitional configuration changes with long token timeouts
- remove a double list_del() when a tracking CFG client shuts down without
  calling cfg_track_stop (it caused corosync to crash)
- use nodeid instead of localhost ip for the case when binding to a loalhost
  interface
- fix corosync shutdown process
- add augeas lense for corosync.conf
- patch to set unset value in token hold cancel structure as to not crash
  wireshark
- convert unsafe function to thread-safe reentrant equivalents
* Mon Feb 22 2010 dmuhamedagic@novell.com
- SP1 beta5 (no code changes)
* Mon Feb  8 2010 dmuhamedagic@novell.com
- turn timestamp off in corosync.conf.example (there was a problem
  reported in connection with not thread-safe glibc functions used
  in concert with this option, which hasn't yet been resolved)
* Wed Jan 27 2010 dmuhamedagic@novell.com
- add cs2646 patch from upstream, fixes cs2642
- add patch to accept on/off for the various log directives (bnc#573451)
* Thu Jan 21 2010 dmuhamedagic@novell.com
- %%pre script moved to openais
* Mon Jan 18 2010 dmuhamedagic@novell.com
- remove init script
- add %%pre script to copy openais.conf and authkey to /etc/corosync
- add patch 2642 (parser fix)
- fix some obsoletes/requires
* Mon Jan 11 2010 lmb@novell.com
- Update to corosync 1.2.0.
* Tue Dec 29 2009 dmuhamedagic@novell.com
- init script changes:
  + replace killall with checkproc, otherwise corosync can't stop
  + test if sbd/lrmadmin exist, because corosync has no dependency
    on cluster-glue
* Tue Dec 15 2009 dmuhamedagic@novell.com
- update to the corosync upstream release 1.2.0
- add suse init script
- don't create rccorosync, because users should be using
  rcopenais to start a cluster
- rename corosynclib to libcorosync4 (similar for the devel package)
  (http://en.opensuse.org/Shared_Library_Packaging_Policy)
- Autotools generated version from the released upstream version 1.2.0
- some specfile changes (initddir -> initrddir, header)
